Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1096)

Unified Diff: Source/devtools/front_end/Script.js

Issue 98953004: DevTools: Introduce Debugger.StackTrace structure in protocol.json (Closed) Base URL: svn://svn.chromium.org/blink/trunk
Patch Set: nits Created 7 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: Source/devtools/front_end/Script.js
diff --git a/Source/devtools/front_end/Script.js b/Source/devtools/front_end/Script.js
index 6f13b7b1f28af5df198eb84a3cd49ed056f464de..85a4a70b5be8289291c9cc87cd4ce1e95eaa6aec 100644
--- a/Source/devtools/front_end/Script.js
+++ b/Source/devtools/front_end/Script.js
@@ -138,7 +138,7 @@ WebInspector.Script.prototype = {
/**
* @param {string} newSource
* @param {function(?Protocol.Error, DebuggerAgent.SetScriptSourceError=, Array.<DebuggerAgent.CallFrame>=, boolean=)} callback
*/
editSource: function(newSource, callback)
{
@@ -148,21 +148,22 @@ WebInspector.Script.prototype = {
* @param {DebuggerAgent.SetScriptSourceError=} errorData
* @param {Array.<DebuggerAgent.CallFrame>=} callFrames
* @param {Object=} debugData
+ * @param {DebuggerAgent.StackTrace=} asyncStackTrace
*/
- function didEditScriptSource(error, errorData, callFrames, debugData)
+ function didEditScriptSource(error, errorData, callFrames, debugData, asyncStackTrace)
{
// FIXME: support debugData.stack_update_needs_step_in flag by calling WebInspector.debugger_model.callStackModified
if (!error)
this._source = newSource;
var needsStepIn = !!debugData && debugData["stack_update_needs_step_in"] === true;
- callback(error, errorData, callFrames, needsStepIn);
+ callback(error, errorData, callFrames, asyncStackTrace, needsStepIn);
if (!error)
this.dispatchEventToListeners(WebInspector.Script.Events.ScriptEdited, newSource);
}
- if (this.scriptId) {
- // Script failed to parse.
+
+ if (this.scriptId)
DebuggerAgent.setScriptSource(this.scriptId, newSource, undefined, didEditScriptSource.bind(this));
- } else
+ else
callback("Script failed to parse");
},
@@ -138,7 +138,7 @@ WebInspector.Script.prototype = {
/**
* @param {string} newSource
- * @param {function(?Protocol.Error, DebuggerAgent.SetScriptSourceError=, Array.<DebuggerAgent.CallFrame>=, boolean=)} callback
+ * @param {function(?Protocol.Error, DebuggerAgent.SetScriptSourceError=, Array.<DebuggerAgent.CallFrame>=, DebuggerAgent.StackTrace=, boolean=)} callback
*/
editSource: function(newSource, callback)

Powered by Google App Engine
This is Rietveld 408576698